﻿using System;
using System.Linq;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace ExtraLargeScaleShapefile
{
    public partial class Form1 : Form
    {
        private string shapefilePath = "../../AppData/digital document of  geography map _lin.shp";
        private ShapeFileFeatureLayer shapeFileFeatureLayer;
        private InMemoryFeatureLayer highlightFeatureLayer;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.Meter;
            ZoomLevelSet zoomLevelSet = new ZoomLevelSet();
            winformsMap1.MaximumScale = 2000000000000000;
            double scale = winformsMap1.MaximumScale;

            for (int i = 0; i < 10; i++)
            {
                scale = scale / 2;
                zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(scale));
            }
            winformsMap1.MinimumScale = scale;
            winformsMap1.ZoomLevelSet = zoomLevelSet;
            winformsMap1.ZoomLevelSnapping = ZoomLevelSnappingMode.None;
            winformsMap1.MapClick += WinformsMap1_MapClick;

            LayerOverlay layerOverlay = new LayerOverlay();
            ShapeFileFeatureSource.BuildIndexFile(shapefilePath, BuildIndexMode.DoNotRebuild);
            shapeFileFeatureLayer = new ShapeFileFeatureLayer(shapefilePath);
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColors.Blue, 2));
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(shapeFileFeatureLayer);

            highlightFeatureLayer = new InMemoryFeatureLayer();
            highlightFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = new LineStyle(new GeoPen(GeoColors.Red, 3));
            highlightFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColors.Green), 5);
            highlightFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layerOverlay.Layers.Add(highlightFeatureLayer);
            winformsMap1.Overlays.Add(layerOverlay);

            shapeFileFeatureLayer.Open();
            winformsMap1.CurrentExtent = shapeFileFeatureLayer.GetBoundingBox();
            winformsMap1.Refresh();
        }

        private void WinformsMap1_MapClick(object sender, MapClickWinformsMapEventArgs e)
        {
            highlightFeatureLayer.InternalFeatures.Clear();

            highlightFeatureLayer.InternalFeatures.Add(new Feature(new PointShape(e.WorldX, e.WorldY)));
            var feature = shapeFileFeatureLayer.FeatureSource.GetFeaturesNearestTo(new RectangleShape(e.WorldX - 1000, e.WorldY + 1000, e.WorldX + 1000, e.WorldY - 1000), GeographyUnit.Meter, 1, ReturningColumnsType.NoColumns);
            if (feature.Count == 1)
                highlightFeatureLayer.InternalFeatures.Add(feature.First());

            winformsMap1.Refresh();
        }
    }
}
